@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -33,41 +35,66 @@
 #' Duplicate Strings
 #'
 #' @description
-#' Duplicates each string \code{times} times
+#' Duplicates each \code{str}(\code{e1}) string \code{times}(\code{e2}) times
 #' and concatenates the results.
 #'
 #' @details
-#' Vectorized over \code{str} and \code{times}.
+#' Vectorized over all arguments.
 #'
-#' @param str a character vector of strings to be duplicated
-#' @param times an integer vector with the numbers of times to duplicate each string
+#' \code{e1 \%s*\% e2} and \code{e1 \%stri*\% e2} are synonyms
+#' for \code{stri_dup(e1, e2)}
 #'
-#' @return Returns a character vector of the same length as \code{str}.
+#' @param str,e1 a character vector of strings to be duplicated
+#' @param times,e2 an integer vector with the numbers of times to duplicate each string
+#'
+#' @return Returns a character vector.
 #'
 #' @export
 #' @family join
+#' @rdname stri_dup
+#' @aliases stri_dup operator_multiply oper_multiply
 #' @examples
-#' stri_dup("a", 1:5)
-#' stri_dup(c("a", NA, "ba"), 4)
-#' stri_dup(c("abc", "pqrst"), c(4, 2))
-stri_dup <- function(str, times) {
-   .Call(C_stri_dup, str, times)
+#' stri_dup('a', 1:5)
+#' stri_dup(c('a', NA, 'ba'), 4)
+#' stri_dup(c('abc', 'pqrst'), c(4, 2))
+#' "a" %s*% 5
+stri_dup <- function(str, times)
+{
+    .Call(C_stri_dup, str, times)
 }
 
 
+#' @usage
+#' e1 \%s*\% e2
+#' @rdname stri_dup
+#' @export
+`%s*%` <- function(e1, e2)
+{
+    .Call(C_stri_dup, e1, e2)
+}
+
+
+#' @usage
+#' e1 \%stri*\% e2
+#' @rdname stri_dup
+#' @export
+`%stri*%` <- `%s*%`
+
+
+
 #' @title
 #' Concatenate Two Character Vectors
 #'
 #' @description
 #' Binary operators for joining (concatenating) two character vectors,
-#' with a typical \R look-and-feel.
+#' with a typical R look-and-feel.
 #'
 #' @details
 #' Vectorized over \code{e1} and \code{e2}.
 #'
-#' These operators act like a call to \code{\link{stri_join}(e1, e2, sep="")}.
-#' However, note that joining 3 vectors, e.g., \code{e1 \%+\% e2 \%+\% e3}
-#' is slower than \code{\link{stri_join}(e1, e2, e3, sep="")},
+#' These operators act like a call to \code{\link{stri_join}(e1, e2, sep='')}.
+#' However, note that joining 3 vectors, e.g., \code{e1 \%s+\% e2 \%s+\% e3}
+#' is slower than \code{\link{stri_join}(e1, e2, e3, sep='')},
 #' because it creates a new (temporary) result vector each time
 #' the operator is applied.
 #'
@@ -79,27 +106,28 @@ stri_dup <- function(str, times) {
 #'
 #'
 #' @examples
-#' c('abc', '123', '\u0105\u0104') %stri+% letters[1:6]
-#' 'ID_' %stri+% 1:5
+#' c('abc', '123', 'xy') %s+% letters[1:6]
+#' 'ID_' %s+% 1:5
 #'
-#' @rdname oper_plus
+#' @rdname operator_add
+#' @aliases oper_plus operator_add operator_plus
+#' @family join
 #'
 #' @usage
 #' e1 \%s+\% e2
 #'
 #' @export
-"%s+%" <- function(e1, e2) {
-   .Call(C_stri_join2, e1, e2)
+`%s+%` <- function(e1, e2)
+{
+    .Call(C_stri_join2, e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri+\% e2
-#' @rdname oper_plus
+#' @rdname operator_add
 #' @export
-"%stri+%" <- function(e1, e2) {
-   .Call(C_stri_join2, e1, e2)
-}
+`%stri+%` <- `%s+%`
 
 
 #' @title
@@ -119,7 +147,7 @@ stri_dup <- function(str, times) {
 #'
 #' If any of the arguments in `\code{...}` is a vector of length 0
 #' (not to be confused with vectors of empty strings)
-#' and \code{ignore_null=FALSE}, then
+#' and \code{ignore_null} is \code{FALSE}, then
 #' you will get a 0-length character vector in result.
 #'
 #' If \code{collapse} or \code{sep} has length greater than 1,
@@ -128,7 +156,7 @@ stri_dup <- function(str, times) {
 #' In case where there are missing values in any of the input vectors,
 #' \code{NA} is set to the corresponding element.
 #' Note that this behavior is different from \code{\link{paste}},
-#' which treats missing values as ordinary strings like \code{"NA"}.
+#' which treats missing values as ordinary strings like \code{'NA'}.
 #' Moreover, as usual in \pkg{stringi}, the resulting strings are
 #' always in UTF-8.
 #'
@@ -138,26 +166,24 @@ stri_dup <- function(str, times) {
 #' @param collapse a single string or \code{NULL}; an optional
 #' results separator
 #' @param ignore_null a single logical value; if \code{TRUE}, then empty
-#' vectors on input are silently ignored
+#' vectors provided via \code{...} are silently ignored
 #'
 #' @return Returns a character vector.
 #'
 #' @export
 #' @examples
 #' stri_join(1:13, letters)
-#' stri_join(1:13, letters, sep='!')
-#' stri_join(1:13, letters, collapse='?')
-#' stri_join(1:13, letters, sep='!', collapse='?')
-#' stri_join(c('abc', '123', '\u0105\u0104'),'###', 1:5, sep='...')
-#' stri_join(c('abc', '123', '\u0105\u0104'),'###', 1:5, sep='...', collapse='?')
-#'
-#' do.call(stri_c, list(c("a", "b", "c"), c("1", "2"), sep='!'))
-#' do.call(stri_c, list(c("a", "b", "c"), c("1", "2"), sep='!', collapse='$'))
+#' stri_join(1:13, letters, sep=',')
+#' stri_join(1:13, letters, collapse='; ')
+#' stri_join(1:13, letters, sep=',', collapse='; ')
+#' stri_join(c('abc', '123', 'xyz'),'###', 1:6, sep=',')
+#' stri_join(c('abc', '123', 'xyz'),'###', 1:6, sep=',', collapse='; ')
 #'
 #' @family join
 #' @rdname stri_join
-stri_join <- function(..., sep="", collapse=NULL, ignore_null=FALSE) {
-   .Call(C_stri_join, list(...), sep, collapse, ignore_null)
+stri_join <- function(..., sep = "", collapse = NULL, ignore_null = FALSE)
+{
+    .Call(C_stri_join, list(...), sep, collapse, ignore_null)
 }
 
 
@@ -179,14 +205,14 @@ stri_paste <- stri_join
 #'
 #' @details
 #' The \code{stri_flatten(str, collapse='XXX')} call
-#' is equivalent to \code{\link{paste}(str, collapse='XXX', sep="")}.
+#' is equivalent to \code{\link{paste}(str, collapse='XXX', sep='')}.
 #'
 #' If you wish to use some more fancy (e.g., differing)
 #' separators between flattened strings,
 #' call \code{\link{stri_join}(str, separators, collapse='')}.
 #'
 #' If \code{str} is not empty, then a single string is returned.
-#' If \code{collapse} has length > 1, then only first string
+#' If \code{collapse} has length > 1, then only the first string
 #' will be used.
 #'
 #' @param str a vector of strings to be coerced to character
@@ -202,15 +228,15 @@ stri_paste <- stri_join
 #'
 #' @examples
 #' stri_flatten(LETTERS)
-#' stri_flatten(LETTERS, collapse=",")
-#' stri_flatten(c('abc', '123', '\u0105\u0104'))
-#' stri_flatten(stri_dup(letters[1:6],1:3))
-#' stri_flatten(c(NA, "", "A", "", "B", NA, "C"), collapse=",", na_empty=TRUE, omit_empty=TRUE)
+#' stri_flatten(LETTERS, collapse=',')
+#' stri_flatten(stri_dup(letters[1:6], 1:3))
+#' stri_flatten(c(NA, '', 'A', '', 'B', NA, 'C'), collapse=',', na_empty=TRUE, omit_empty=TRUE)
 #'
 #' @export
 #' @family join
-stri_flatten <- function(str, collapse="", na_empty=FALSE, omit_empty=FALSE) {
-   .Call(C_stri_flatten, str, collapse, na_empty, omit_empty)
+stri_flatten <- function(str, collapse = "", na_empty = FALSE, omit_empty = FALSE)
+{
+    .Call(C_stri_flatten, str, collapse, na_empty, omit_empty)
 }
 
 
@@ -243,21 +269,34 @@ stri_flatten <- function(str, collapse="", na_empty=FALSE, omit_empty=FALSE) {
 #'
 #' @export
 #' @examples
-#' stri_join_list(stri_extract_all_words(c("Lorem ipsum dolor sit amet.",
-#' "Get a life.")), sep=", ")
+#' stri_join_list(
+#'    stri_extract_all_words(c('Lorem ipsum dolor sit amet.',
+#'    'Spam spam bacon sausage and spam.')),
+#' sep=', ')
 #'
-#' stri_join_list(stri_extract_all_words(c("Lorem ipsum dolor sit amet.",
-#' "Get a life.")), sep=", ", collapse=". ")
+#' stri_join_list(
+#'    stri_extract_all_words(c('Lorem ipsum dolor sit amet.',
+#'    'Spam spam bacon sausage and spam.')),
+#' sep=', ', collapse='. ')
 #'
-#' stri_join_list(stri_extract_all_regex(c("R is OK.", "123 456", "Hey!"), "\\p{L}+"), " ")
+#' stri_join_list(
+#'    stri_extract_all_regex(
+#'       c('spam spam bacon', '123 456', 'spam 789 sausage'), '\\p{L}+'
+#'    ),
+#' sep=',')
 #'
-#' stri_join_list(stri_extract_all_regex(c("R is OK.", "123 456", "Hey!"),
-#' "\\p{L}+", omit_no_match=TRUE), " ", " -- ")
+#' stri_join_list(
+#'    stri_extract_all_regex(
+#'       c('spam spam bacon', '123 456', 'spam 789 sausage'), '\\p{L}+',
+#'       omit_no_match=TRUE
+#'    ),
+#' sep=',', collapse='; ')
 #'
 #' @family join
 #' @rdname stri_join_list
-stri_join_list <- function(x, sep="", collapse=NULL) {
-   .Call(C_stri_join_list, x, sep, collapse)
+stri_join_list <- function(x, sep = "", collapse = NULL)
+{
+    .Call(C_stri_join_list, x, sep, collapse)
 }
 
 
