@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -70,7 +72,7 @@
 #' @export
 #' @family length
 stri_numbytes <- function(str) {
-   .Call(C_stri_numbytes, str)
+    .Call(C_stri_numbytes, str)
 }
 
 
@@ -107,12 +109,13 @@ stri_numbytes <- function(str) {
 #' stri_numbytes('\u0105') # 2 bytes are used
 #' stri_numbytes(stri_trans_nfkd('\u0105')) # 3 bytes here but...
 #' stri_length(stri_trans_nfkd('\u0105')) # ...two code points (!)
-#' stri_count_boundaries(stri_trans_nfkd('\u0105'), type="character") # ...and one Unicode character
+#' stri_count_boundaries(stri_trans_nfkd('\u0105'), type='character') # ...and one Unicode character
 #'
 #' @export
 #' @family length
-stri_length <- function(str) {
-   .Call(C_stri_length, str)
+stri_length <- function(str)
+{
+    .Call(C_stri_length, str)
 }
 
 
@@ -136,8 +139,9 @@ stri_length <- function(str) {
 #'
 #' @export
 #' @family length
-stri_isempty <- function(str) {
-   .Call(C_stri_isempty, str)
+stri_isempty <- function(str)
+{
+    .Call(C_stri_isempty, str)
 }
 
 
@@ -150,8 +154,9 @@ stri_isempty <- function(str) {
 #'
 #' @details
 #' The Unicode standard does not formalize the notion of a character
-#' width. Roughly based on \url{http://www.cl.cam.ac.uk/~mgk25/ucs/wcwidth.c}
-#' and the UAX #11 we proceed as follows.
+#' width. Roughly based on \url{https://www.cl.cam.ac.uk/~mgk25/ucs/wcwidth.c},
+#' \url{https://github.com/nodejs/node/blob/master/src/node_i18n.cc},
+#' and UAX #11 we proceed as follows.
 #' The following code points are of width 0:
 #' \itemize{
 #' \item code points with general category (see \link{stringi-search-charclass})
@@ -165,9 +170,14 @@ stri_isempty <- function(str) {
 #' is encouraged),
 #' \item ZERO WIDTH SPACE (U+200B),
 #' }
+#'
 #' Characters with the \code{UCHAR_EAST_ASIAN_WIDTH} enumerable property
 #' equal to \code{U_EA_FULLWIDTH} or \code{U_EA_WIDE} are
 #' of width 2.
+#'
+#' Most emojis and characters with general category So (other symbols)
+#' are of width 2.
+#'
 #' SOFT HYPHEN (U+00AD) (for compatibility with \code{\link{nchar}})
 #' as well as any other characters have width 1.
 #'
@@ -176,17 +186,19 @@ stri_isempty <- function(str) {
 #'
 #' @examples
 #' stri_width(LETTERS[1:5])
-#' stri_width(stri_trans_nfkd("\u0105"))
+#' stri_width(stri_trans_nfkd('\u0105'))
+#' stri_width(stri_trans_nfkd('\U0001F606'))
 #' stri_width( # Full-width equivalents of ASCII characters:
 #'    stri_enc_fromutf32(as.list(c(0x3000, 0xFF01:0xFF5E)))
 #' )
-#' stri_width(stri_trans_nfkd("\ubc1f")) # includes Hangul Jamo medial vowels and final consonants
+#' stri_width(stri_trans_nfkd('\ubc1f')) # includes Hangul Jamo medial vowels and final consonants
 #' @export
 #' @family length
 #'
 #' @references
 #' \emph{East Asian Width} -- Unicode Standard Annex #11,
-#' \url{http://www.unicode.org/reports/tr11/}
-stri_width <- function(str) {
-   .Call(C_stri_width, str)
+#' \url{https://www.unicode.org/reports/tr11/}
+stri_width <- function(str)
+{
+    .Call(C_stri_width, str)
 }
