@@ -1,5 +1,5 @@
-/* This file is part of the 'stringi' package for R.
- * Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
+/* This file is part of the 'stringi' project.
+ * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,9 +34,10 @@
 #define __stri_external_h
 
 
-#ifdef U_CHARSET_IS_UTF8
+#ifdef  U_CHARSET_IS_UTF8
 // do not enable this (must be unset before including ICU headers):
-#undef U_CHARSET_IS_UTF8
+#undef  U_CHARSET_IS_UTF8
+#define U_CHARSET_IS_UTF8 0
 #endif
 
 //#ifndef NDEBUG
@@ -64,6 +65,7 @@ using namespace icu;
 #define USE_RINTERNALS
 #define R_NO_REMAP
 #include <R.h>
+#include <Rversion.h>
 #include <Rinternals.h>
 #include <Rmath.h>
 #include <Rdefines.h>
