@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -1147,6 +1147,9 @@ const char* stri__prepare_arg_string_1_notNA(SEXP x, const char* argname)
  *
  * @version 0.5-1 (Marek Gagolewski, 2015-01-01)
  *    "@keyword=value" may use default locale from now; also, loc is trimmed
+ *
+ * @version 1.5.4 (Marek Gagolewski, 2021-04-07)
+ *    BUGFIX: locale='' is the default
  */
 const char* stri__prepare_arg_locale(SEXP loc, const char* argname, bool allowdefault, bool allowna)
 {
@@ -1159,6 +1162,11 @@ const char* stri__prepare_arg_locale(SEXP loc, const char* argname, bool allowde
             if (allowna) return NULL;
             else Rf_error(MSG__ARG_EXPECTED_NOT_NA, argname); // Rf_error allowed here
         }
+        if (strlen((const char*)CHAR(STRING_ELT(loc, 0))) == 0) {
+            UNPROTECT(1);
+            if (allowdefault) return uloc_getDefault();
+            else Rf_error(MSG__LOCALE_INCORRECT_ID); // Rf_error allowed here
+        }
 
         UErrorCode err = U_ZERO_ERROR;
         char buf[ULOC_FULLNAME_CAPACITY];
