@@ -1,5 +1,5 @@
-/* This file is part of the 'stringi' package for R.
- * Copyright (C) 2013-2016, Marek Gagolewski and Bartek Tartanus
+/* This file is part of the 'stringi' project.
+ * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,6 +40,8 @@
  *
  * @param str R character vector
  * @param pattern R character vector containing regular expressions
+ * @param negate single bool
+ * @param max_count single int
  * @param opts_regex list
  *
  * @version 0.1-?? (Marcin Bujarski)
@@ -61,37 +63,56 @@
  *
  * @version 1.0-3 (Marek Gagolewski, 2016-02-03)
  *    FR #216: `negate` arg added
+ *
+ * @version 1.3.1 (Marek Gagolewski, 2019-02-08)
+ *    #232: `max_count` arg added
+ *
+ * @version 1.4.7 (Marek Gagolewski, 2020-08-24)
+ *    Use StriContainerRegexPattern::getRegexOptions
  */
-SEXP stri_detect_regex(SEXP str, SEXP pattern, SEXP negate, SEXP opts_regex)
+SEXP stri_detect_regex(SEXP str, SEXP pattern, SEXP negate,
+                       SEXP max_count, SEXP opts_regex)
 {
-   bool negate_1 = stri__prepare_arg_logical_1_notNA(negate, "negate");
-   PROTECT(str = stri_prepare_arg_string(str, "str"));
-   PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
-   R_len_t vectorize_length =
-      stri__recycling_rule(true, 2, LENGTH(str), LENGTH(pattern));
+    bool negate_1 = stri__prepare_arg_logical_1_notNA(negate, "negate");
+    int max_count_1 = stri__prepare_arg_integer_1_notNA(max_count, "max_count");
+    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
+    R_len_t vectorize_length =
+        stri__recycling_rule(true, 2, LENGTH(str), LENGTH(pattern));
 
-   uint32_t pattern_flags = StriContainerRegexPattern::getRegexFlags(opts_regex);
+    StriRegexMatcherOptions pattern_opts =
+        StriContainerRegexPattern::getRegexOptions(opts_regex);
 
-   STRI__ERROR_HANDLER_BEGIN(2)
-   StriContainerUTF16 str_cont(str, vectorize_length);
+    STRI__ERROR_HANDLER_BEGIN(2)
+    StriContainerUTF16 str_cont(str, vectorize_length);
 //   StriContainerUTF8 str_cont(str, vectorize_length); // utext_openUTF8, see below
-   StriContainerRegexPattern pattern_cont(pattern, vectorize_length, pattern_flags);
+    StriContainerRegexPattern pattern_cont(pattern, vectorize_length, pattern_opts);
 
-   SEXP ret;
-   STRI__PROTECT(ret = Rf_allocVector(LGLSXP, vectorize_length));
-   int* ret_tab = LOGICAL(ret);
+    SEXP ret;
+    STRI__PROTECT(ret = Rf_allocVector(LGLSXP, vectorize_length));
+    int* ret_tab = LOGICAL(ret);
 
-   for (R_len_t i = pattern_cont.vectorize_init();
-         i != pattern_cont.vectorize_end();
-         i = pattern_cont.vectorize_next(i))
-   {
-      STRI__CONTINUE_ON_EMPTY_OR_NA_PATTERN(str_cont,
-         pattern_cont, ret_tab[i] = NA_LOGICAL)
+    for (R_len_t i = pattern_cont.vectorize_init();
+            i != pattern_cont.vectorize_end();
+            i = pattern_cont.vectorize_next(i))
+    {
+        if (max_count_1 == 0) {
+            ret_tab[i] = NA_LOGICAL;
+            continue;
+        }
 
-      RegexMatcher *matcher = pattern_cont.getMatcher(i); // will be deleted automatically
-      matcher->reset(str_cont.get(i));
-      ret_tab[i] = (int)matcher->find(); // returns UBool
-      if (negate_1) ret_tab[i] = !ret_tab[i];
+        STRI__CONTINUE_ON_EMPTY_OR_NA_PATTERN(str_cont,
+                                              pattern_cont, ret_tab[i] = NA_LOGICAL)
+
+        RegexMatcher *matcher = pattern_cont.getMatcher(i); // will be deleted automatically
+        matcher->reset(str_cont.get(i));
+
+        UErrorCode status = U_ZERO_ERROR;
+        ret_tab[i] = (int)matcher->find(status); // returns UBool
+        STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+
+        if (negate_1) ret_tab[i] = !ret_tab[i];
+        if (max_count_1 > 0 && ret_tab[i]) --max_count_1;
 
 //      // mbmark-regex-detect1.R: UTF16 0.07171792 s; UText 0.10531605 s
 //      UText* str_text = NULL;
@@ -100,11 +121,11 @@ SEXP stri_detect_regex(SEXP str, SEXP pattern, SEXP negate, SEXP opts_regex)
 //      str_text = utext_openUTF8(str_text, str_cont.get(i).c_str(), str_cont.get(i).length(), &status);
 //      STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 //      matcher->reset(str_text);
-//      ret_tab[i] = (int)matcher->find(); // returns UBool
+//      ret_tab[i] = (int)matcher->find(status); // returns UBool
 //      utext_close(str_text);
-   }
+    }
 
-   STRI__UNPROTECT_ALL
-   return ret;
-   STRI__ERROR_HANDLER_END(;/* nothing special to be done on error */)
+    STRI__UNPROTECT_ALL
+    return ret;
+    STRI__ERROR_HANDLER_END(;/* nothing special to be done on error */)
 }
